<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Редактиране</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Име:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="40"/>
        <source>Search...</source>
        <translation>Търсене...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="54"/>
        <source>Start only in X11</source>
        <translation>Стартиране само в X11</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="30"/>
        <source>Command:</source>
        <translation>Команда:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Wait for system tray</source>
        <translation>Изчакване на системната област за известяване</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="67"/>
        <source>Select Application</source>
        <translation>Избиране на приложение</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Глобално автоматично стартиращи програми</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>LXQt автоматично стартиращи програми</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Местоположение: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Презаписване: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="51"/>
        <source>Delete</source>
        <translation>Изтриване</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="37"/>
        <source>Add</source>
        <translation>Добавяне</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Edit</source>
        <translation>Редактиране</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="23"/>
        <source>Application Autostart</source>
        <translation>Приложения</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="145"/>
        <location filename="../autostartpage.cpp" line="156"/>
        <location filename="../autostartpage.cpp" line="175"/>
        <location filename="../autostartpage.cpp" line="180"/>
        <location filename="../autostartpage.cpp" line="197"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="175"/>
        <source>Please provide Name and Command</source>
        <translation>Моля, посочете име и команда</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="145"/>
        <location filename="../autostartpage.cpp" line="180"/>
        <source>Name should not start with dot or contain slash</source>
        <translation>Името не трябва да започва с точка или да съдържа наклонена черта</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="156"/>
        <location filename="../autostartpage.cpp" line="197"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Файл &apos;%1&apos; вече съществува!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Основни настройки</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Мениджър на прозорци</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <location filename="../basicsettings.ui" line="226"/>
        <source>Search...</source>
        <translation>Търсене...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQt Модули</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="81"/>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="88"/>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Under Wayland, adjust scaling via compositor settings or kanshi instead.</source>
        <translation>Под Wayland регулирайте мащабирането чрез настройките на композитора или kanshi.</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="114"/>
        <source>Global Screen Scaling</source>
        <translation>Глобално мащабиране на екрана</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="126"/>
        <source>Scale factor:</source>
        <translation>Фактор на мащаб:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="152"/>
        <source>Leave Session</source>
        <translation>Излизане от сесията</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="158"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Изискване на потвърждение за напускане на сесия</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="165"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Заключване на екрана преди приспиване/хибернация</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="172"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>При приспиване и хибернация заключване след:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="185"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="201"/>
        <source>Use custom screen lock command</source>
        <translation>Използване на персонализирана команда за заключване на екрана</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="200"/>
        <source>Select a window manager</source>
        <translation>Избиране на мениджър на прозорци</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="215"/>
        <source>Select a screenlocker</source>
        <translation>Избиране на програма за заключване на екрана</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="47"/>
        <source>Add</source>
        <translation>Добавяне</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="54"/>
        <source>Delete</source>
        <translation>Изтриване</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="23"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Променливи на средата (разширени настройки)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="34"/>
        <source>Variable Name</source>
        <translation>Име на променлива</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="39"/>
        <source>Value</source>
        <translation>Стойност</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Стартиран</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="45"/>
        <source>LXQt Session Settings</source>
        <translation>Настройки на сесията</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="48"/>
        <source>Basic Settings</source>
        <translation>Основни настройки</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="54"/>
        <source>User Directories</source>
        <translation>Потребителски директории</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="60"/>
        <source>Autostart</source>
        <translation>Автоматично стартиране на програми</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="67"/>
        <source>Wayland Settings</source>
        <translation>Настройки на Wayland</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="74"/>
        <source>Environment (Advanced)</source>
        <translation>Променливи на средата(разширени настройки)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="100"/>
        <source>Session Restart Required</source>
        <translation>Необходимо е рестартиране на сесията</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="101"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Някои настройки няма да влязат в сила до следващото влизане.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Местоположения за персоналните файлове</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Настройки на сесията LXQt - Потребителски директории</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error occurred while applying the settings for the %1 location</source>
        <translation>Възникна грешка при прилагане на настройките за местоположение %1</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Избиране на местоположение</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Работен плот</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Свалени</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Шаблони</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Споделени</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Снимки</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Съдържа всички файлове, които виждате на вашия работен плот</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Папка по подразбиране за свалените файлове</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Папка по подразбиране за шаблоните</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Папка по подразбиране за споделените файлове</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Папка по подразбиране за документи</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Папка по подразбиране за съхраняване на музика</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Папка по подразбиране за снимки и изображения</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Папка по подразбиране за съхраняване на видео</translation>
    </message>
</context>
<context>
    <name>WaylandSettings</name>
    <message>
        <location filename="../waylandsettings.ui" line="23"/>
        <source>Wayland Settings</source>
        <translation>Настройки на Wayland</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="30"/>
        <source>Wayland compositor</source>
        <translation>Композитор на Wayland</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="49"/>
        <location filename="../waylandsettings.ui" line="81"/>
        <source>Search...</source>
        <translation>Търсене...</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="59"/>
        <source>Screenlock command</source>
        <translation>Команда за заключване на екрана:</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="71"/>
        <source>Use &quot;loginctl lock-session&quot; on kwin_wayland</source>
        <translation>Използване на &quot;loginctl lock-session&quot; при kwin_wayland</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="98"/>
        <source>Select a Wayland Compositor</source>
        <translation>Избор на композитор на Wayland</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="103"/>
        <source>Select a Screenlocker for Wayland</source>
        <translation>Избор на програма за заключване на екрана на Wayland</translation>
    </message>
</context>
</TS>
